Lingtypology

## LingTypology¶

LingTypology is a package that tries to bring functionality of the R package of the same name.
By now `lingtypology` is able to create interactive linguistic maps and has API for several linguistic databases.
There is a tutorial that allows to start using `lingtypology`:

1. Interactive linguistic maps
2. Glottolog
3. API for Wals, Autotyp etc.
4. Documentation

## Credits ¶

This Python package is inspired by the R package made by agricolamz.
Also this module uses JavaScript library Leaflet and its Python-wrapper Folium and Branca.
Also, special thanks to Xrotwang for helping me with the package.

## Citation ¶

It will be most appreciated if you cite `lingtypology`. To find out the recommended way to do so, consult the readme.

## License ¶

Copyright (C) 2018-2019 Michael Voronov

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.